<template>
  <ProDialog
    title="导入"
    v-model="visible"
    @close="onDialogClose"
    destroy-on-close
    draggable
    width="700px"
  >
    <ProForm :model="form" ref="dialogForm" label-width="120px">
      <ProFormItemV2
        label="上传文件:"
        prop="url"
        :check-rules="[{ message: '请上传文件', type: 'upload' }]"
      >
        <ProFormUpload v-model:file-url="form.url" accept="xlsx,xls"></ProFormUpload>
      </ProFormItemV2>
      <ProFormItemV2
        label="上传凭证:"
        prop="certificateUrl"
        :check-rules="[{ message: '请上传凭证', type: 'upload' }]"
      >
        <ProFormUpload
          v-model:file-url="form.certificateUrl"
          :limitFileSize="50"
          accept="doc,docx,pdf,xls,xlsx,jpg/jpeg,png"
        ></ProFormUpload>
      </ProFormItemV2>
    </ProForm>
    <template #footer>
      <span class="dialog-footer">
        <el-button @click="emit('onCancel')">取 消</el-button>
        <el-button type="primary" @click="handleConfirm">确 定</el-button>
      </span>
    </template>
  </ProDialog>
</template>

<script setup lang="ts">
import { FormInstance } from 'element-plus';
import {
  ProDialog,
  ProForm,
  ProFormItemV2,
  UploadUserFile,
  ProFormUpload,
} from '@bole-core/components';

defineOptions({
  name: 'UploadCertRewardDialog',
});

const visible = defineModel({ type: Boolean });

type Form = {
  title?: string;
  certificateUrl: UploadUserFile[];
  url: UploadUserFile[];
  parkBountyApplyId: string;
};

const form = defineModel<Form>('form');

const emit = defineEmits<{
  (e: 'onConfirm'): void;
  (e: 'onCancel'): void;
}>();

const dialogForm = ref<FormInstance>();

function onDialogClose() {
  if (!dialogForm.value) return;
  dialogForm.value.resetFields();
}

function handleConfirm() {
  if (!dialogForm.value) return;
  dialogForm.value.validate((valid) => {
    if (valid) {
      emit('onConfirm');
    } else {
      return;
    }
  });
}
</script>
